'use strict';

var _rollupPluginBabelHelpers = require('./_rollupPluginBabelHelpers-9bd7278f.js');
var React = require('react');
var styledComponents_esm = require('./styled-components.esm-2ab54698.js');
var theme = require('./theme-35090651.js');
var Avatar = require('./index-db8a1014.js');
var Paragraph = require('./index-b0ff74ec.js');
var Icon = require('./Icon.js');
var mixins = require('./mixins-11271831.js');
var Text = require('./Text.js');
var Badge = require('./Badge.js');
require('./style-3dc964d3.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

const Title = styledComponents_esm.Ye(Text)`
  grid-area: title;
`;
const RightLabel = styledComponents_esm.Ye(Text)`
  grid-area: label;
  justify-self: end;
`;
const SubTitle = styledComponents_esm.Ye(Text)`
  grid-area: subtitle;
`;
const Description = styledComponents_esm.Ye.div`
  grid-area: description;
  display: grid;
  grid-template-columns: 30px 1fr 30px;
  align-items: center;
  ${({
  replied
}) => replied && styledComponents_esm._e`
      grid-template-columns: 24px 1fr 30px;
    `}
`;
const UnreadBadge = styledComponents_esm.Ye(Badge)`
  justify-self: end;
`;
const StyledCard = styledComponents_esm.Ye.div`
  ${mixins.card()};
  display: grid;
  grid-template-areas:
    "avatar title label"
    "avatar subtitle subtitle"
    "description description description";
  grid-template-columns: 64px 1fr 1fr;
  row-gap: 16px;
  background: ${({
  background
}) => background};
  transition: 0.4s;
  &:hover {
    box-shadow: 0px 20px 50px rgba(0, 0, 0, 0.1);
  }

  ${Avatar.AvatarWrapper} {
    grid-area: avatar;
  }

  ${({
  active
}) => active && styledComponents_esm._e`
      background: ${({
  theme
}) => theme.darkPurple};
      ${Title}, ${SubTitle}, ${RightLabel}, ${Paragraph.StyledParagraph} {
        color: white;
      }
      ${SubTitle}, ${RightLabel} {
        opacity: 0.4;
      }
      ${mixins.activeBar({
  barWidth: '4px',
  shadowWidth: '14px'
})}
      overflow: hidden;`}
`;

function Card({
  children,
  background = '#fff',
  avatarUrl,
  avatarStatus,
  title,
  subtitle,
  rightLabel,
  description,
  count,
  active,
  iconSvg,
  ...rest
}) {
  return /*#__PURE__*/React__default['default'].createElement(styledComponents_esm.Le, {
    theme: theme.theme
  }, /*#__PURE__*/React__default['default'].createElement(StyledCard, _rollupPluginBabelHelpers._extends({
    active: active
  }, rest, {
    background: background
  }), /*#__PURE__*/React__default['default'].createElement(Avatar.Avatar, {
    status: avatarStatus,
    src: avatarUrl
  }), /*#__PURE__*/React__default['default'].createElement(Title, null, title), /*#__PURE__*/React__default['default'].createElement(SubTitle, null, subtitle), /*#__PURE__*/React__default['default'].createElement(RightLabel, null, rightLabel), /*#__PURE__*/React__default['default'].createElement(Description, null, iconSvg && /*#__PURE__*/React__default['default'].createElement(Icon, {
    width: 16,
    height: 14,
    icon: iconSvg,
    color: active ? theme.theme.inactiveColorDark : theme.theme.inactiveColor,
    opacity: active ? 0.4 : 1,
    style: {
      justifyContent: 'start'
    }
  }), /*#__PURE__*/React__default['default'].createElement(Paragraph.Paragraph, null, description), /*#__PURE__*/React__default['default'].createElement(UnreadBadge, {
    count: count
  }))));
}

Card.propTypes = {
  children: styledComponents_esm.propTypes.any,
  background: styledComponents_esm.propTypes.string,
  avatarUrl: styledComponents_esm.propTypes.string,
  title: styledComponents_esm.propTypes.string,
  subtitle: styledComponents_esm.propTypes.string,
  rightLabel: styledComponents_esm.propTypes.string,
  description: styledComponents_esm.propTypes.string,
  count: styledComponents_esm.propTypes.number,
  avatarStatus: styledComponents_esm.propTypes.any,
  active: styledComponents_esm.propTypes.bool,
  iconSvg: styledComponents_esm.propTypes.any
};

module.exports = Card;
