import { _ as _extends } from './_rollupPluginBabelHelpers-1b8c042f.js';
import React from 'react';
import { Y as Ye, _ as _e, L as Le, p as propTypes } from './styled-components.esm-9e557172.js';
import { t as theme } from './theme-b7be7677.js';
import { a as AvatarWrapper, A as Avatar } from './index-981d0acc.js';
import { S as StyledParagraph, P as Paragraph } from './index-a59d20e7.js';
import Icon from './Icon.js';
import { b as card, a as activeBar } from './mixins-2c3cffa6.js';
import Text from './Text.js';
import Badge from './Badge.js';
import './style-8160c220.js';

const Title = Ye(Text)`
  grid-area: title;
`;
const RightLabel = Ye(Text)`
  grid-area: label;
  justify-self: end;
`;
const SubTitle = Ye(Text)`
  grid-area: subtitle;
`;
const Description = Ye.div`
  grid-area: description;
  display: grid;
  grid-template-columns: 30px 1fr 30px;
  align-items: center;
  ${({
  replied
}) => replied && _e`
      grid-template-columns: 24px 1fr 30px;
    `}
`;
const UnreadBadge = Ye(Badge)`
  justify-self: end;
`;
const StyledCard = Ye.div`
  ${card()};
  display: grid;
  grid-template-areas:
    "avatar title label"
    "avatar subtitle subtitle"
    "description description description";
  grid-template-columns: 64px 1fr 1fr;
  row-gap: 16px;
  background: ${({
  background
}) => background};
  transition: 0.4s;
  &:hover {
    box-shadow: 0px 20px 50px rgba(0, 0, 0, 0.1);
  }

  ${AvatarWrapper} {
    grid-area: avatar;
  }

  ${({
  active
}) => active && _e`
      background: ${({
  theme
}) => theme.darkPurple};
      ${Title}, ${SubTitle}, ${RightLabel}, ${StyledParagraph} {
        color: white;
      }
      ${SubTitle}, ${RightLabel} {
        opacity: 0.4;
      }
      ${activeBar({
  barWidth: '4px',
  shadowWidth: '14px'
})}
      overflow: hidden;`}
`;

function Card({
  children,
  background = '#fff',
  avatarUrl,
  avatarStatus,
  title,
  subtitle,
  rightLabel,
  description,
  count,
  active,
  iconSvg,
  ...rest
}) {
  return /*#__PURE__*/React.createElement(Le, {
    theme: theme
  }, /*#__PURE__*/React.createElement(StyledCard, _extends({
    active: active
  }, rest, {
    background: background
  }), /*#__PURE__*/React.createElement(Avatar, {
    status: avatarStatus,
    src: avatarUrl
  }), /*#__PURE__*/React.createElement(Title, null, title), /*#__PURE__*/React.createElement(SubTitle, null, subtitle), /*#__PURE__*/React.createElement(RightLabel, null, rightLabel), /*#__PURE__*/React.createElement(Description, null, iconSvg && /*#__PURE__*/React.createElement(Icon, {
    width: 16,
    height: 14,
    icon: iconSvg,
    color: active ? theme.inactiveColorDark : theme.inactiveColor,
    opacity: active ? 0.4 : 1,
    style: {
      justifyContent: 'start'
    }
  }), /*#__PURE__*/React.createElement(Paragraph, null, description), /*#__PURE__*/React.createElement(UnreadBadge, {
    count: count
  }))));
}

Card.propTypes = {
  children: propTypes.any,
  background: propTypes.string,
  avatarUrl: propTypes.string,
  title: propTypes.string,
  subtitle: propTypes.string,
  rightLabel: propTypes.string,
  description: propTypes.string,
  count: propTypes.number,
  avatarStatus: propTypes.any,
  active: propTypes.bool,
  iconSvg: propTypes.any
};

export default Card;
